/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsISupports.idl"
#include "nsIPluginInstance.idl"

%{C++
#include "nsPluginNativeWindow.h"
%}

interface nsIPluginInstanceOwner;

[ptr] native nsPluginNativeWindowPtr(nsPluginNativeWindow);

[uuid(75d8fcd7-06d1-4767-9022-7f8dacf48a68)]
interface nsPIPluginHost : nsISupports
{
 /**
  * To notify the plugin manager that the plugin created a script object 
  */
  void setIsScriptableInstance(in nsIPluginInstance aInstance, in boolean aScriptable);

 /**
  * This method parses post buffer to find out case insensitive "Content-length" string
  * and CR or LF some where after that, then it assumes there is http headers in
  * the input buffer and continue to search for end of headers (CRLFCRLF or LFLF).
  * It will *always malloc()* output buffer (caller is responsible to free it) 
  * if input buffer starts with LF, which comes from 4.x spec 
  * http://developer.netscape.com/docs/manuals/communicator/plugin/pgfn2.htm#1007754
  * "If no custom headers are required, simply add a blank
  * line ('\n') to the beginning of the file or buffer.",
  * it skips that '\n' and considers rest of the input buffer as data.
  * If "Content-length" string and end of headers is found 
  *   it substitutes single LF with CRLF in the headers, so the end of headers
  *   always will be CRLFCRLF (single CR in headers, if any, remain untouched)
  * else
  *   it puts "Content-length: "+size_of_data+CRLFCRLF at the beginning of the output buffer
  * and memcpy data to the output buffer 
  *
  * On failure outPostData and outPostDataLen will be set in 0.  
  * @param aInPostData      - the post data
  * @param aInPostDataLen   - the length aInPostData
  * @param aOutPostData     - the buffer
  * @param aOutPostDataLen  - the length of aOutPostData
  **/
  void parsePostBufferToFixHeaders(in string aInPostData, 
                                   in unsigned long aInPostDataLen, 
                                   out string aOutPostData, 
                                   out unsigned long aOutPostDataLen);
 /**
  * To create tmp file with Content len header in, it will use by http POST
  */
  void createTmpFileToPost(in string aPostDataURL, out string aTmpFileName);

 /**
  *  Creates a new plugin native window object
  */
  void newPluginNativeWindow(out nsPluginNativeWindowPtr aPluginNativeWindow);

 /**
  *  Deletes plugin native window object created by NewPluginNativeWindow
  */
  void deletePluginNativeWindow(in nsPluginNativeWindowPtr aPluginNativeWindow);
  /**
   * Instantiate a "dummy" java plugin if a java plugin that supports
   * NPRuntime is installed. This plugin is used for exposing
   * window.java and window.Packages. If the java plugin supports
   * NPRuntime and instantiation was successful, aOwners instance will
   * be non-null, if not, it will be null.
   */
  [noscript] void instantiateDummyJavaPlugin(in nsIPluginInstanceOwner aOwner);

 /**
  * Get the plugin name for the plugin instance.
  */
  [noscript] void getPluginName(in nsIPluginInstance aInstance, out string aPluginName);
};
